==> linkv_rtc_im_mini-0.0.4.tar.gz: lib/linkv_rtm_callback.dart <==

class LVIMEventCallback {
  /// 收到IM消息
  /// @param msg 收到的消息模型
  void onIMMessageReceive(var msg) {}

  /// 已读回执通知
  /// @param msgid 消息ID
  void onIMMessageReaded(int msgId) {}

  /// 根据时间戳设置的已读回执通知
  /// @param sessionid 会话ID，私聊时为对方的uid，群组时为群组id
  /// @param stime 时间戳
  void onIMMessageReadedForStime(String sessionid, int stime) {}

  /// 收到IM事件类型消息
  /// @param msg 收到的消息模型
  void onEventMessageReceive(var msg) {}

  /// 收到已读类型IM消息
  /// @param msg 收到的消息模型
  /// @param stime 时间戳，所有<=stime的消息都应该更新为已读
  void onReadMessageReceive(var msg, int stime) {}

  /// 请求token的事件，从自己的服务端请求到IM的token之后，调用RtmFlutterPlugin.setIMToken
  void onQueryIMToken() {}

  /// 认证失败事件
  /// @param uid 用户ID
  /// @param token IM的token
  /// @param error_code 错误码
  /// @param rcode 响应码
  /// @param expired 是否过期了
  void onIMAuthFailed(String uid, String token, int ecode, int rcode, bool isTokenExpired) {}

  /// 认证成功事件
  /// @param uid 用户ID
  /// @param token IM的token
  /// @param unReadMsgSize 未读消息数量(粗略)
  void onIMAuthSucceed(String uid, String token, int unReadMsgSize) {}

  /// 认证成功事件
  /// @param uid 用户ID
  /// @param token IM的token
  /// @param owner 所属者
  void onIMTokenExpired(String uid, String token) {}

  /// 连接成功事件
  void onIMConnected() {}

  /// 连接断开事件
  void onIMLosted() {}

  /// 用户被封禁回调
  /// @param uid 用户ID
  /// @param code 错误码
  void onIMUserKicked(String uid, int code) {}

  /// 即时通讯连接状态回调
  /// @param connectState 连接状态
  void onIMConnectState(int connectState) {}

  /// 发送IM消息回调
  /// @param msg 收到的消息模型
  void onIMSendMessageReceive(int ecode, int rcode, var msg) {}

}

==> linkv_rtc_im_mini-0.0.5.tar.gz: lib/linkv_rtm_callback.dart <==

class LVIMEventCallback {
  /// 收到IM消息
  /// @param msg 收到的消息模型
  void onIMMessageReceive(var msg) {}

  /// 已读回执通知
  /// @param msgid 消息ID
  void onIMMessageReaded(int msgId) {}

  /// 根据时间戳设置的已读回执通知
  /// @param sessionid 会话ID，私聊时为对方的uid，群组时为群组id
  /// @param stime 时间戳
  void onIMMessageReadedForStime(String sessionid, int stime) {}

  /// 收到IM事件类型消息
  /// @param msg 收到的消息模型
  void onEventMessageReceive(var msg) {}

  /// 收到已读类型IM消息
  /// @param msg 收到的消息模型
  /// @param stime 时间戳，所有<=stime的消息都应该更新为已读
  void onReadMessageReceive(var msg, int stime) {}

  /// 请求token的事件，从自己的服务端请求到IM的token之后，调用RtmFlutterPlugin.setIMToken
  void onQueryIMToken() {}

  /// 认证失败事件
  /// @param uid 用户ID
  /// @param token IM的token
  /// @param eCode 错误码
  /// @param rCode 响应码
  /// @param isTokenExpired 是否过期了
  void onIMAuthFailed(String uid, String token, int eCode, int rCode, bool isTokenExpired) {}

  /// 认证成功事件
  /// @param uid 用户ID
  /// @param token IM的token
  /// @param unReadMsgSize 未读消息数量(粗略)
  void onIMAuthSucceed(String uid, String token, int unReadMsgSize) {}

  /// 认证成功事件
  /// @param uid 用户ID
  /// @param token IM的token
  /// @param owner 所属者
  void onIMTokenExpired(String uid, String token) {}

  /// 连接成功事件
  void onIMConnected() {}

  /// 连接断开事件
  void onIMLosted() {}

  /// 用户被封禁回调
  /// @param uid 用户ID
  /// @param code 错误码
  void onIMUserKicked(String uid, int code) {}

  /// 即时通讯连接状态回调
  /// @param connectState 连接状态
  void onIMConnectState(int connectState) {}

  /// 发送IM消息回调
  /// @param eCode 客户端状态码，0为成功，非0为失败
  /// @param rCode 服务器状态码，0为成功，非0为失败
  /// @param msg 收到的消息模型
  void onIMSendMessageReceive(int eCode, int rCode, var msg) {}

}
